@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 10247 2017-09-03 17:57:32Z David $
+# $Id: urls.py 10827 2018-03-11 15:11:03Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-09-04 01:57:32 +0800 (Mon, 04 Sep 2017) $
-# $Revision: 10247 $
+# $Date: 2018-03-11 23:11:03 +0800 (Sun, 11 Mar 2018) $
+# $Revision: 10827 $
 
 from django.conf.urls import url, patterns
 
@@ -35,4 +35,15 @@ urlpatterns = patterns('',
 
     url(r'^notificationTopic/set/$', views.setNotificationTopic,
         name='Theophrastus.cloud.ajax.setNotificationTopic'),
+    
+    # resend error contact.
+    url(r'^newsletters/resend/(?P<newsletterId>\w+)',
+        views.resendErrorContact, name='resendErrorContact'),
+    # view error details
+     url(
+        r'^tracking/historic/(?P<slug>[-\w]+)/errors/'
+        r'(?P<contactMailingStatusId>\w+)',
+        views.viewErrorDetails,
+        name='Theophrastus.cloud.views.viewErrorDetails'),
+
 )
