@@ -15,4 +15,4 @@
 # $Date: 2013-05-16 06:52:28 +0000 (週四, 16 五月 2013) $
 # $Revision: 9166 $
 
-from Theophrastus.models import *
+from emencia.django.newsletter.models import *
